# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SenderRange(Base):
	"""The SenderRange class encapsulates a user managed senderRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SenderRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'senderRange'

	def __init__(self, parent):
		super(SenderRange, self).__init__(parent)

	@property
	def TunnelHeadToLeaf(self):
		"""An instance of the TunnelHeadToLeaf class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.rsvp.tunnelheadtoleaf.TunnelHeadToLeaf)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.rsvp.tunnelheadtoleaf import TunnelHeadToLeaf
		return TunnelHeadToLeaf(self)

	@property
	def TunnelHeadTrafficEndPoint(self):
		"""An instance of the TunnelHeadTrafficEndPoint class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.rsvp.tunnelheadtrafficendpoint.TunnelHeadTrafficEndPoint)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.rsvp.tunnelheadtrafficendpoint import TunnelHeadTrafficEndPoint
		return TunnelHeadTrafficEndPoint(self)

	@property
	def AutoGenerateSessionName(self):
		"""If enabled, the session name is generated automatically. If it is not enabled, the session name field is activated and must be filled in.

		Returns:
			bool
		"""
		return self._get_attribute('autoGenerateSessionName')
	@AutoGenerateSessionName.setter
	def AutoGenerateSessionName(self, value):
		self._set_attribute('autoGenerateSessionName', value)

	@property
	def BackupLspIdPoolStart(self):
		"""It helps to set the LSP Id for the re-optimized LSP.

		Returns:
			number
		"""
		return self._get_attribute('backupLspIdPoolStart')
	@BackupLspIdPoolStart.setter
	def BackupLspIdPoolStart(self, value):
		self._set_attribute('backupLspIdPoolStart', value)

	@property
	def Bandwidth(self):
		"""The bandwidth requested for the connection, expressed in kbits/sec.

		Returns:
			number
		"""
		return self._get_attribute('bandwidth')
	@Bandwidth.setter
	def Bandwidth(self, value):
		self._set_attribute('bandwidth', value)

	@property
	def BandwidthProtectionDesired(self):
		"""Indicates that PLRs should skip at least the next node for a backup path.

		Returns:
			bool
		"""
		return self._get_attribute('bandwidthProtectionDesired')
	@BandwidthProtectionDesired.setter
	def BandwidthProtectionDesired(self, value):
		self._set_attribute('bandwidthProtectionDesired', value)

	@property
	def EnableBfdMpls(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableBfdMpls')
	@EnableBfdMpls.setter
	def EnableBfdMpls(self, value):
		self._set_attribute('enableBfdMpls', value)

	@property
	def EnableFastReroute(self):
		"""Enables the use of the fast reroute feature.

		Returns:
			bool
		"""
		return self._get_attribute('enableFastReroute')
	@EnableFastReroute.setter
	def EnableFastReroute(self, value):
		self._set_attribute('enableFastReroute', value)

	@property
	def EnableLspPing(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLspPing')
	@EnableLspPing.setter
	def EnableLspPing(self, value):
		self._set_attribute('enableLspPing', value)

	@property
	def EnablePathReoptimization(self):
		"""If true, enables the Path Re-optimization option.

		Returns:
			bool
		"""
		return self._get_attribute('enablePathReoptimization')
	@EnablePathReoptimization.setter
	def EnablePathReoptimization(self, value):
		self._set_attribute('enablePathReoptimization', value)

	@property
	def EnablePeriodicReEvaluationRequest(self):
		"""If true, enables the head LSR to send periodic path re-evaluation request in every Re-Optimization Interval.

		Returns:
			bool
		"""
		return self._get_attribute('enablePeriodicReEvaluationRequest')
	@EnablePeriodicReEvaluationRequest.setter
	def EnablePeriodicReEvaluationRequest(self, value):
		self._set_attribute('enablePeriodicReEvaluationRequest', value)

	@property
	def EnableResourceAffinities(self):
		"""Enables the use of RSVP resource class affinities for LSP tunnels.

		Returns:
			bool
		"""
		return self._get_attribute('enableResourceAffinities')
	@EnableResourceAffinities.setter
	def EnableResourceAffinities(self, value):
		self._set_attribute('enableResourceAffinities', value)

	@property
	def Enabled(self):
		"""Enables the sender range entry.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def ExcludeAny(self):
		"""Represents a set of attribute filters associated with a tunnel, any of which renders a link unacceptable.

		Returns:
			number
		"""
		return self._get_attribute('excludeAny')
	@ExcludeAny.setter
	def ExcludeAny(self, value):
		self._set_attribute('excludeAny', value)

	@property
	def FastRerouteBandwidth(self):
		"""An estimate of the bandwidth needed for the protection path.

		Returns:
			number
		"""
		return self._get_attribute('fastRerouteBandwidth')
	@FastRerouteBandwidth.setter
	def FastRerouteBandwidth(self, value):
		self._set_attribute('fastRerouteBandwidth', value)

	@property
	def FastRerouteDetour(self):
		"""Used to provide backup LSP tunnels for local repair of LSP tunnels, in the event of failure of a node or link. Contains the specifics of the detour LSPs: nodes to use and nodes to avoid.

		Returns:
			list(dict(arg1:str,arg2:str))
		"""
		return self._get_attribute('fastRerouteDetour')
	@FastRerouteDetour.setter
	def FastRerouteDetour(self, value):
		self._set_attribute('fastRerouteDetour', value)

	@property
	def FastRerouteExcludeAny(self):
		"""Capability filters used to dictate which backup paths are acceptable or unacceptable.

		Returns:
			number
		"""
		return self._get_attribute('fastRerouteExcludeAny')
	@FastRerouteExcludeAny.setter
	def FastRerouteExcludeAny(self, value):
		self._set_attribute('fastRerouteExcludeAny', value)

	@property
	def FastRerouteFacilityBackupDesired(self):
		"""If enabled, indicates that facility backup should be used. With this method, the MPLS label stack allows the creation of a bypass tunnel to protect a set of LSPs with similar characteristics/constraints. Protects both links and nodes.

		Returns:
			bool
		"""
		return self._get_attribute('fastRerouteFacilityBackupDesired')
	@FastRerouteFacilityBackupDesired.setter
	def FastRerouteFacilityBackupDesired(self, value):
		self._set_attribute('fastRerouteFacilityBackupDesired', value)

	@property
	def FastRerouteHoldingPriority(self):
		"""The priority value for the backup path, pertaining to holding resources - whether a session can be preempted BY another session.

		Returns:
			number
		"""
		return self._get_attribute('fastRerouteHoldingPriority')
	@FastRerouteHoldingPriority.setter
	def FastRerouteHoldingPriority(self, value):
		self._set_attribute('fastRerouteHoldingPriority', value)

	@property
	def FastRerouteHopLimit(self):
		"""Indicates the number of extra hops that may be added by a protection path.

		Returns:
			number
		"""
		return self._get_attribute('fastRerouteHopLimit')
	@FastRerouteHopLimit.setter
	def FastRerouteHopLimit(self, value):
		self._set_attribute('fastRerouteHopLimit', value)

	@property
	def FastRerouteIncludeAll(self):
		"""Capability filters used to dictate which backup paths are acceptable or unacceptable.

		Returns:
			number
		"""
		return self._get_attribute('fastRerouteIncludeAll')
	@FastRerouteIncludeAll.setter
	def FastRerouteIncludeAll(self, value):
		self._set_attribute('fastRerouteIncludeAll', value)

	@property
	def FastRerouteIncludeAny(self):
		"""Capability filters used to dictate which backup paths are acceptable or unacceptable.

		Returns:
			number
		"""
		return self._get_attribute('fastRerouteIncludeAny')
	@FastRerouteIncludeAny.setter
	def FastRerouteIncludeAny(self, value):
		self._set_attribute('fastRerouteIncludeAny', value)

	@property
	def FastRerouteOne2OneBackupDesired(self):
		"""If enabled, indicates that one-to-one backup should be used. With this method, one detour LSP will be created for each protected LSP for each place where the LSP could potentially be repaired locally. Protects both links and nodes.

		Returns:
			bool
		"""
		return self._get_attribute('fastRerouteOne2OneBackupDesired')
	@FastRerouteOne2OneBackupDesired.setter
	def FastRerouteOne2OneBackupDesired(self, value):
		self._set_attribute('fastRerouteOne2OneBackupDesired', value)

	@property
	def FastRerouteSendDetour(self):
		"""Enables the generation of a DETOUR object for one to one operation.

		Returns:
			bool
		"""
		return self._get_attribute('fastRerouteSendDetour')
	@FastRerouteSendDetour.setter
	def FastRerouteSendDetour(self, value):
		self._set_attribute('fastRerouteSendDetour', value)

	@property
	def FastRerouteSetupPriority(self):
		"""Indicate the priority for taking and holding resources along the backup path.

		Returns:
			number
		"""
		return self._get_attribute('fastRerouteSetupPriority')
	@FastRerouteSetupPriority.setter
	def FastRerouteSetupPriority(self, value):
		self._set_attribute('fastRerouteSetupPriority', value)

	@property
	def HoldingPriority(self):
		"""Priority in holding onto resources. Range is 0 to 7, with 0 the highest priority.

		Returns:
			number
		"""
		return self._get_attribute('holdingPriority')
	@HoldingPriority.setter
	def HoldingPriority(self, value):
		self._set_attribute('holdingPriority', value)

	@property
	def IncludeAll(self):
		"""32-bit value. Represents a set of attribute filters associated with a tunnel, all of which must be present for a link to be acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.

		Returns:
			number
		"""
		return self._get_attribute('includeAll')
	@IncludeAll.setter
	def IncludeAll(self, value):
		self._set_attribute('includeAll', value)

	@property
	def IncludeAny(self):
		"""32-bit value. Represents a set of attribute filters associated with a tunnel, any of which makes a link acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.

		Returns:
			number
		"""
		return self._get_attribute('includeAny')
	@IncludeAny.setter
	def IncludeAny(self, value):
		self._set_attribute('includeAny', value)

	@property
	def IpCount(self):
		"""The number of routers in the destination range.

		Returns:
			number
		"""
		return self._get_attribute('ipCount')
	@IpCount.setter
	def IpCount(self, value):
		self._set_attribute('ipCount', value)

	@property
	def IpStart(self):
		"""The IP address of the first destination router.

		Returns:
			str
		"""
		return self._get_attribute('ipStart')
	@IpStart.setter
	def IpStart(self, value):
		self._set_attribute('ipStart', value)

	@property
	def LabelRecordingDesired(self):
		"""If enabled, indicates that label information is to be included when doing a route record.

		Returns:
			bool
		"""
		return self._get_attribute('labelRecordingDesired')
	@LabelRecordingDesired.setter
	def LabelRecordingDesired(self, value):
		self._set_attribute('labelRecordingDesired', value)

	@property
	def LocalProtectionDesired(self):
		"""(Enabled by default) This permits transit routers to use a local traffic rerouting repair mechanism in the event of a fault on an adjacent downstream link or node. This may result in a violation of the explicit route object.

		Returns:
			bool
		"""
		return self._get_attribute('localProtectionDesired')
	@LocalProtectionDesired.setter
	def LocalProtectionDesired(self, value):
		self._set_attribute('localProtectionDesired', value)

	@property
	def LspIdCount(self):
		"""The number of LSP IDs in the range.

		Returns:
			number
		"""
		return self._get_attribute('lspIdCount')
	@LspIdCount.setter
	def LspIdCount(self, value):
		self._set_attribute('lspIdCount', value)

	@property
	def LspIdStart(self):
		"""The first label-switched path ID (LSP ID) value in the range of LSP IDs.

		Returns:
			number
		"""
		return self._get_attribute('lspIdStart')
	@LspIdStart.setter
	def LspIdStart(self, value):
		self._set_attribute('lspIdStart', value)

	@property
	def MaximumPacketSize(self):
		"""32-bit integer. The maximum number of bytes allowed to cross the interface in a transmitted packet.

		Returns:
			number
		"""
		return self._get_attribute('maximumPacketSize')
	@MaximumPacketSize.setter
	def MaximumPacketSize(self, value):
		self._set_attribute('maximumPacketSize', value)

	@property
	def MinimumPolicedUnit(self):
		"""32-bit integer. The minimum allowable size for a policed unit.

		Returns:
			number
		"""
		return self._get_attribute('minimumPolicedUnit')
	@MinimumPolicedUnit.setter
	def MinimumPolicedUnit(self, value):
		self._set_attribute('minimumPolicedUnit', value)

	@property
	def NodeProtectionDesired(self):
		"""For Fast Reroute - if enabled, sets the Node Protection Desired Flag in the Session_Attribute object of the RRO message. It indicates to PLRs associated with the protected LSP path, that a backup path is desired that bypasses (avoids) at least the next node on the LSP.

		Returns:
			bool
		"""
		return self._get_attribute('nodeProtectionDesired')
	@NodeProtectionDesired.setter
	def NodeProtectionDesired(self, value):
		self._set_attribute('nodeProtectionDesired', value)

	@property
	def PathTearTlv(self):
		"""A set of custom TLVs to be included in TEAR messages, constructed with the rsvpCustomTlv command.

		Returns:
			list(dict(arg1:number,arg2:number,arg3:str))
		"""
		return self._get_attribute('pathTearTlv')
	@PathTearTlv.setter
	def PathTearTlv(self, value):
		self._set_attribute('pathTearTlv', value)

	@property
	def PathTlv(self):
		"""A set of custom TLVs to be included in PATH messages, constructed with the rsvpCustomTlv command.

		Returns:
			list(dict(arg1:number,arg2:number,arg3:str))
		"""
		return self._get_attribute('pathTlv')
	@PathTlv.setter
	def PathTlv(self, value):
		self._set_attribute('pathTlv', value)

	@property
	def PeakDataRate(self):
		"""The maximum traffic rate that can be maintained. The policing mechanism allows some burstiness, but restricts it so the overall packet transmission rate is less than the rate at which tokens.

		Returns:
			number
		"""
		return self._get_attribute('peakDataRate')
	@PeakDataRate.setter
	def PeakDataRate(self, value):
		self._set_attribute('peakDataRate', value)

	@property
	def ReEvaluationRequestInterval(self):
		"""Represents the time period (in milliseconds) at which the path re-evaluation request is sent by the head LSR. The default value is: 180000 ms (3 mins).

		Returns:
			number
		"""
		return self._get_attribute('reEvaluationRequestInterval')
	@ReEvaluationRequestInterval.setter
	def ReEvaluationRequestInterval(self, value):
		self._set_attribute('reEvaluationRequestInterval', value)

	@property
	def RefreshInterval(self):
		"""The interval between summary refresh messages.

		Returns:
			number
		"""
		return self._get_attribute('refreshInterval')
	@RefreshInterval.setter
	def RefreshInterval(self, value):
		self._set_attribute('refreshInterval', value)

	@property
	def SeStyleDesired(self):
		"""This indicates that the tunnel ingress node may reroute this tunnel without tearing it down. A tunnel egress node should use the SE Style when responding with an RESV message.

		Returns:
			bool
		"""
		return self._get_attribute('seStyleDesired')
	@SeStyleDesired.setter
	def SeStyleDesired(self, value):
		self._set_attribute('seStyleDesired', value)

	@property
	def SessionName(self):
		"""If enableAutoSessionName is not set, this is the name assigned to this session.

		Returns:
			str
		"""
		return self._get_attribute('sessionName')
	@SessionName.setter
	def SessionName(self, value):
		self._set_attribute('sessionName', value)

	@property
	def SetupPriority(self):
		"""This is the session priority with respect to taking resources, such as preempting another session. The valid range is from 0 to 7. The highest priority is indicated by 0.

		Returns:
			number
		"""
		return self._get_attribute('setupPriority')
	@SetupPriority.setter
	def SetupPriority(self, value):
		self._set_attribute('setupPriority', value)

	@property
	def TimeoutMultiplier(self):
		"""The number of Hellos before a neighbor is declared dead.

		Returns:
			number
		"""
		return self._get_attribute('timeoutMultiplier')
	@TimeoutMultiplier.setter
	def TimeoutMultiplier(self, value):
		self._set_attribute('timeoutMultiplier', value)

	@property
	def TokenBucketRate(self):
		"""The rate of transfer for data in a flow. In this application, it is used with a traffic policing mechanism. The data tokens enter the bucket, filling the bucket. The data from a number of tokens is combined to form and send a packet. The goal is to determine a rate which will not overflow the specified token bucket size, and cause new data (tokens) to be rejected/discarded.

		Returns:
			number
		"""
		return self._get_attribute('tokenBucketRate')
	@TokenBucketRate.setter
	def TokenBucketRate(self, value):
		self._set_attribute('tokenBucketRate', value)

	@property
	def TokenBucketSize(self):
		"""The maximum capacity (in bytes) the token bucket can hold, and above which newly received tokens cannot be processed and are discarded.

		Returns:
			number
		"""
		return self._get_attribute('tokenBucketSize')
	@TokenBucketSize.setter
	def TokenBucketSize(self, value):
		self._set_attribute('tokenBucketSize', value)

	def update(self, AutoGenerateSessionName=None, BackupLspIdPoolStart=None, Bandwidth=None, BandwidthProtectionDesired=None, EnableBfdMpls=None, EnableFastReroute=None, EnableLspPing=None, EnablePathReoptimization=None, EnablePeriodicReEvaluationRequest=None, EnableResourceAffinities=None, Enabled=None, ExcludeAny=None, FastRerouteBandwidth=None, FastRerouteDetour=None, FastRerouteExcludeAny=None, FastRerouteFacilityBackupDesired=None, FastRerouteHoldingPriority=None, FastRerouteHopLimit=None, FastRerouteIncludeAll=None, FastRerouteIncludeAny=None, FastRerouteOne2OneBackupDesired=None, FastRerouteSendDetour=None, FastRerouteSetupPriority=None, HoldingPriority=None, IncludeAll=None, IncludeAny=None, IpCount=None, IpStart=None, LabelRecordingDesired=None, LocalProtectionDesired=None, LspIdCount=None, LspIdStart=None, MaximumPacketSize=None, MinimumPolicedUnit=None, NodeProtectionDesired=None, PathTearTlv=None, PathTlv=None, PeakDataRate=None, ReEvaluationRequestInterval=None, RefreshInterval=None, SeStyleDesired=None, SessionName=None, SetupPriority=None, TimeoutMultiplier=None, TokenBucketRate=None, TokenBucketSize=None):
		"""Updates a child instance of senderRange on the server.

		Args:
			AutoGenerateSessionName (bool): If enabled, the session name is generated automatically. If it is not enabled, the session name field is activated and must be filled in.
			BackupLspIdPoolStart (number): It helps to set the LSP Id for the re-optimized LSP.
			Bandwidth (number): The bandwidth requested for the connection, expressed in kbits/sec.
			BandwidthProtectionDesired (bool): Indicates that PLRs should skip at least the next node for a backup path.
			EnableBfdMpls (bool): NOT DEFINED
			EnableFastReroute (bool): Enables the use of the fast reroute feature.
			EnableLspPing (bool): NOT DEFINED
			EnablePathReoptimization (bool): If true, enables the Path Re-optimization option.
			EnablePeriodicReEvaluationRequest (bool): If true, enables the head LSR to send periodic path re-evaluation request in every Re-Optimization Interval.
			EnableResourceAffinities (bool): Enables the use of RSVP resource class affinities for LSP tunnels.
			Enabled (bool): Enables the sender range entry.
			ExcludeAny (number): Represents a set of attribute filters associated with a tunnel, any of which renders a link unacceptable.
			FastRerouteBandwidth (number): An estimate of the bandwidth needed for the protection path.
			FastRerouteDetour (list(dict(arg1:str,arg2:str))): Used to provide backup LSP tunnels for local repair of LSP tunnels, in the event of failure of a node or link. Contains the specifics of the detour LSPs: nodes to use and nodes to avoid.
			FastRerouteExcludeAny (number): Capability filters used to dictate which backup paths are acceptable or unacceptable.
			FastRerouteFacilityBackupDesired (bool): If enabled, indicates that facility backup should be used. With this method, the MPLS label stack allows the creation of a bypass tunnel to protect a set of LSPs with similar characteristics/constraints. Protects both links and nodes.
			FastRerouteHoldingPriority (number): The priority value for the backup path, pertaining to holding resources - whether a session can be preempted BY another session.
			FastRerouteHopLimit (number): Indicates the number of extra hops that may be added by a protection path.
			FastRerouteIncludeAll (number): Capability filters used to dictate which backup paths are acceptable or unacceptable.
			FastRerouteIncludeAny (number): Capability filters used to dictate which backup paths are acceptable or unacceptable.
			FastRerouteOne2OneBackupDesired (bool): If enabled, indicates that one-to-one backup should be used. With this method, one detour LSP will be created for each protected LSP for each place where the LSP could potentially be repaired locally. Protects both links and nodes.
			FastRerouteSendDetour (bool): Enables the generation of a DETOUR object for one to one operation.
			FastRerouteSetupPriority (number): Indicate the priority for taking and holding resources along the backup path.
			HoldingPriority (number): Priority in holding onto resources. Range is 0 to 7, with 0 the highest priority.
			IncludeAll (number): 32-bit value. Represents a set of attribute filters associated with a tunnel, all of which must be present for a link to be acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.
			IncludeAny (number): 32-bit value. Represents a set of attribute filters associated with a tunnel, any of which makes a link acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.
			IpCount (number): The number of routers in the destination range.
			IpStart (str): The IP address of the first destination router.
			LabelRecordingDesired (bool): If enabled, indicates that label information is to be included when doing a route record.
			LocalProtectionDesired (bool): (Enabled by default) This permits transit routers to use a local traffic rerouting repair mechanism in the event of a fault on an adjacent downstream link or node. This may result in a violation of the explicit route object.
			LspIdCount (number): The number of LSP IDs in the range.
			LspIdStart (number): The first label-switched path ID (LSP ID) value in the range of LSP IDs.
			MaximumPacketSize (number): 32-bit integer. The maximum number of bytes allowed to cross the interface in a transmitted packet.
			MinimumPolicedUnit (number): 32-bit integer. The minimum allowable size for a policed unit.
			NodeProtectionDesired (bool): For Fast Reroute - if enabled, sets the Node Protection Desired Flag in the Session_Attribute object of the RRO message. It indicates to PLRs associated with the protected LSP path, that a backup path is desired that bypasses (avoids) at least the next node on the LSP.
			PathTearTlv (list(dict(arg1:number,arg2:number,arg3:str))): A set of custom TLVs to be included in TEAR messages, constructed with the rsvpCustomTlv command.
			PathTlv (list(dict(arg1:number,arg2:number,arg3:str))): A set of custom TLVs to be included in PATH messages, constructed with the rsvpCustomTlv command.
			PeakDataRate (number): The maximum traffic rate that can be maintained. The policing mechanism allows some burstiness, but restricts it so the overall packet transmission rate is less than the rate at which tokens.
			ReEvaluationRequestInterval (number): Represents the time period (in milliseconds) at which the path re-evaluation request is sent by the head LSR. The default value is: 180000 ms (3 mins).
			RefreshInterval (number): The interval between summary refresh messages.
			SeStyleDesired (bool): This indicates that the tunnel ingress node may reroute this tunnel without tearing it down. A tunnel egress node should use the SE Style when responding with an RESV message.
			SessionName (str): If enableAutoSessionName is not set, this is the name assigned to this session.
			SetupPriority (number): This is the session priority with respect to taking resources, such as preempting another session. The valid range is from 0 to 7. The highest priority is indicated by 0.
			TimeoutMultiplier (number): The number of Hellos before a neighbor is declared dead.
			TokenBucketRate (number): The rate of transfer for data in a flow. In this application, it is used with a traffic policing mechanism. The data tokens enter the bucket, filling the bucket. The data from a number of tokens is combined to form and send a packet. The goal is to determine a rate which will not overflow the specified token bucket size, and cause new data (tokens) to be rejected/discarded.
			TokenBucketSize (number): The maximum capacity (in bytes) the token bucket can hold, and above which newly received tokens cannot be processed and are discarded.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, AutoGenerateSessionName=None, BackupLspIdPoolStart=None, Bandwidth=None, BandwidthProtectionDesired=None, EnableBfdMpls=None, EnableFastReroute=None, EnableLspPing=None, EnablePathReoptimization=None, EnablePeriodicReEvaluationRequest=None, EnableResourceAffinities=None, Enabled=None, ExcludeAny=None, FastRerouteBandwidth=None, FastRerouteDetour=None, FastRerouteExcludeAny=None, FastRerouteFacilityBackupDesired=None, FastRerouteHoldingPriority=None, FastRerouteHopLimit=None, FastRerouteIncludeAll=None, FastRerouteIncludeAny=None, FastRerouteOne2OneBackupDesired=None, FastRerouteSendDetour=None, FastRerouteSetupPriority=None, HoldingPriority=None, IncludeAll=None, IncludeAny=None, IpCount=None, IpStart=None, LabelRecordingDesired=None, LocalProtectionDesired=None, LspIdCount=None, LspIdStart=None, MaximumPacketSize=None, MinimumPolicedUnit=None, NodeProtectionDesired=None, PathTearTlv=None, PathTlv=None, PeakDataRate=None, ReEvaluationRequestInterval=None, RefreshInterval=None, SeStyleDesired=None, SessionName=None, SetupPriority=None, TimeoutMultiplier=None, TokenBucketRate=None, TokenBucketSize=None):
		"""Adds a new senderRange node on the server and retrieves it in this instance.

		Args:
			AutoGenerateSessionName (bool): If enabled, the session name is generated automatically. If it is not enabled, the session name field is activated and must be filled in.
			BackupLspIdPoolStart (number): It helps to set the LSP Id for the re-optimized LSP.
			Bandwidth (number): The bandwidth requested for the connection, expressed in kbits/sec.
			BandwidthProtectionDesired (bool): Indicates that PLRs should skip at least the next node for a backup path.
			EnableBfdMpls (bool): NOT DEFINED
			EnableFastReroute (bool): Enables the use of the fast reroute feature.
			EnableLspPing (bool): NOT DEFINED
			EnablePathReoptimization (bool): If true, enables the Path Re-optimization option.
			EnablePeriodicReEvaluationRequest (bool): If true, enables the head LSR to send periodic path re-evaluation request in every Re-Optimization Interval.
			EnableResourceAffinities (bool): Enables the use of RSVP resource class affinities for LSP tunnels.
			Enabled (bool): Enables the sender range entry.
			ExcludeAny (number): Represents a set of attribute filters associated with a tunnel, any of which renders a link unacceptable.
			FastRerouteBandwidth (number): An estimate of the bandwidth needed for the protection path.
			FastRerouteDetour (list(dict(arg1:str,arg2:str))): Used to provide backup LSP tunnels for local repair of LSP tunnels, in the event of failure of a node or link. Contains the specifics of the detour LSPs: nodes to use and nodes to avoid.
			FastRerouteExcludeAny (number): Capability filters used to dictate which backup paths are acceptable or unacceptable.
			FastRerouteFacilityBackupDesired (bool): If enabled, indicates that facility backup should be used. With this method, the MPLS label stack allows the creation of a bypass tunnel to protect a set of LSPs with similar characteristics/constraints. Protects both links and nodes.
			FastRerouteHoldingPriority (number): The priority value for the backup path, pertaining to holding resources - whether a session can be preempted BY another session.
			FastRerouteHopLimit (number): Indicates the number of extra hops that may be added by a protection path.
			FastRerouteIncludeAll (number): Capability filters used to dictate which backup paths are acceptable or unacceptable.
			FastRerouteIncludeAny (number): Capability filters used to dictate which backup paths are acceptable or unacceptable.
			FastRerouteOne2OneBackupDesired (bool): If enabled, indicates that one-to-one backup should be used. With this method, one detour LSP will be created for each protected LSP for each place where the LSP could potentially be repaired locally. Protects both links and nodes.
			FastRerouteSendDetour (bool): Enables the generation of a DETOUR object for one to one operation.
			FastRerouteSetupPriority (number): Indicate the priority for taking and holding resources along the backup path.
			HoldingPriority (number): Priority in holding onto resources. Range is 0 to 7, with 0 the highest priority.
			IncludeAll (number): 32-bit value. Represents a set of attribute filters associated with a tunnel, all of which must be present for a link to be acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.
			IncludeAny (number): 32-bit value. Represents a set of attribute filters associated with a tunnel, any of which makes a link acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.
			IpCount (number): The number of routers in the destination range.
			IpStart (str): The IP address of the first destination router.
			LabelRecordingDesired (bool): If enabled, indicates that label information is to be included when doing a route record.
			LocalProtectionDesired (bool): (Enabled by default) This permits transit routers to use a local traffic rerouting repair mechanism in the event of a fault on an adjacent downstream link or node. This may result in a violation of the explicit route object.
			LspIdCount (number): The number of LSP IDs in the range.
			LspIdStart (number): The first label-switched path ID (LSP ID) value in the range of LSP IDs.
			MaximumPacketSize (number): 32-bit integer. The maximum number of bytes allowed to cross the interface in a transmitted packet.
			MinimumPolicedUnit (number): 32-bit integer. The minimum allowable size for a policed unit.
			NodeProtectionDesired (bool): For Fast Reroute - if enabled, sets the Node Protection Desired Flag in the Session_Attribute object of the RRO message. It indicates to PLRs associated with the protected LSP path, that a backup path is desired that bypasses (avoids) at least the next node on the LSP.
			PathTearTlv (list(dict(arg1:number,arg2:number,arg3:str))): A set of custom TLVs to be included in TEAR messages, constructed with the rsvpCustomTlv command.
			PathTlv (list(dict(arg1:number,arg2:number,arg3:str))): A set of custom TLVs to be included in PATH messages, constructed with the rsvpCustomTlv command.
			PeakDataRate (number): The maximum traffic rate that can be maintained. The policing mechanism allows some burstiness, but restricts it so the overall packet transmission rate is less than the rate at which tokens.
			ReEvaluationRequestInterval (number): Represents the time period (in milliseconds) at which the path re-evaluation request is sent by the head LSR. The default value is: 180000 ms (3 mins).
			RefreshInterval (number): The interval between summary refresh messages.
			SeStyleDesired (bool): This indicates that the tunnel ingress node may reroute this tunnel without tearing it down. A tunnel egress node should use the SE Style when responding with an RESV message.
			SessionName (str): If enableAutoSessionName is not set, this is the name assigned to this session.
			SetupPriority (number): This is the session priority with respect to taking resources, such as preempting another session. The valid range is from 0 to 7. The highest priority is indicated by 0.
			TimeoutMultiplier (number): The number of Hellos before a neighbor is declared dead.
			TokenBucketRate (number): The rate of transfer for data in a flow. In this application, it is used with a traffic policing mechanism. The data tokens enter the bucket, filling the bucket. The data from a number of tokens is combined to form and send a packet. The goal is to determine a rate which will not overflow the specified token bucket size, and cause new data (tokens) to be rejected/discarded.
			TokenBucketSize (number): The maximum capacity (in bytes) the token bucket can hold, and above which newly received tokens cannot be processed and are discarded.

		Returns:
			self: This instance with all currently retrieved senderRange data using find and the newly added senderRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the senderRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AutoGenerateSessionName=None, BackupLspIdPoolStart=None, Bandwidth=None, BandwidthProtectionDesired=None, EnableBfdMpls=None, EnableFastReroute=None, EnableLspPing=None, EnablePathReoptimization=None, EnablePeriodicReEvaluationRequest=None, EnableResourceAffinities=None, Enabled=None, ExcludeAny=None, FastRerouteBandwidth=None, FastRerouteDetour=None, FastRerouteExcludeAny=None, FastRerouteFacilityBackupDesired=None, FastRerouteHoldingPriority=None, FastRerouteHopLimit=None, FastRerouteIncludeAll=None, FastRerouteIncludeAny=None, FastRerouteOne2OneBackupDesired=None, FastRerouteSendDetour=None, FastRerouteSetupPriority=None, HoldingPriority=None, IncludeAll=None, IncludeAny=None, IpCount=None, IpStart=None, LabelRecordingDesired=None, LocalProtectionDesired=None, LspIdCount=None, LspIdStart=None, MaximumPacketSize=None, MinimumPolicedUnit=None, NodeProtectionDesired=None, PathTearTlv=None, PathTlv=None, PeakDataRate=None, ReEvaluationRequestInterval=None, RefreshInterval=None, SeStyleDesired=None, SessionName=None, SetupPriority=None, TimeoutMultiplier=None, TokenBucketRate=None, TokenBucketSize=None):
		"""Finds and retrieves senderRange data from the server.

		All named parameters support regex and can be used to selectively retrieve senderRange data from the server.
		By default the find method takes no parameters and will retrieve all senderRange data from the server.

		Args:
			AutoGenerateSessionName (bool): If enabled, the session name is generated automatically. If it is not enabled, the session name field is activated and must be filled in.
			BackupLspIdPoolStart (number): It helps to set the LSP Id for the re-optimized LSP.
			Bandwidth (number): The bandwidth requested for the connection, expressed in kbits/sec.
			BandwidthProtectionDesired (bool): Indicates that PLRs should skip at least the next node for a backup path.
			EnableBfdMpls (bool): NOT DEFINED
			EnableFastReroute (bool): Enables the use of the fast reroute feature.
			EnableLspPing (bool): NOT DEFINED
			EnablePathReoptimization (bool): If true, enables the Path Re-optimization option.
			EnablePeriodicReEvaluationRequest (bool): If true, enables the head LSR to send periodic path re-evaluation request in every Re-Optimization Interval.
			EnableResourceAffinities (bool): Enables the use of RSVP resource class affinities for LSP tunnels.
			Enabled (bool): Enables the sender range entry.
			ExcludeAny (number): Represents a set of attribute filters associated with a tunnel, any of which renders a link unacceptable.
			FastRerouteBandwidth (number): An estimate of the bandwidth needed for the protection path.
			FastRerouteDetour (list(dict(arg1:str,arg2:str))): Used to provide backup LSP tunnels for local repair of LSP tunnels, in the event of failure of a node or link. Contains the specifics of the detour LSPs: nodes to use and nodes to avoid.
			FastRerouteExcludeAny (number): Capability filters used to dictate which backup paths are acceptable or unacceptable.
			FastRerouteFacilityBackupDesired (bool): If enabled, indicates that facility backup should be used. With this method, the MPLS label stack allows the creation of a bypass tunnel to protect a set of LSPs with similar characteristics/constraints. Protects both links and nodes.
			FastRerouteHoldingPriority (number): The priority value for the backup path, pertaining to holding resources - whether a session can be preempted BY another session.
			FastRerouteHopLimit (number): Indicates the number of extra hops that may be added by a protection path.
			FastRerouteIncludeAll (number): Capability filters used to dictate which backup paths are acceptable or unacceptable.
			FastRerouteIncludeAny (number): Capability filters used to dictate which backup paths are acceptable or unacceptable.
			FastRerouteOne2OneBackupDesired (bool): If enabled, indicates that one-to-one backup should be used. With this method, one detour LSP will be created for each protected LSP for each place where the LSP could potentially be repaired locally. Protects both links and nodes.
			FastRerouteSendDetour (bool): Enables the generation of a DETOUR object for one to one operation.
			FastRerouteSetupPriority (number): Indicate the priority for taking and holding resources along the backup path.
			HoldingPriority (number): Priority in holding onto resources. Range is 0 to 7, with 0 the highest priority.
			IncludeAll (number): 32-bit value. Represents a set of attribute filters associated with a tunnel, all of which must be present for a link to be acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.
			IncludeAny (number): 32-bit value. Represents a set of attribute filters associated with a tunnel, any of which makes a link acceptable (with respect to this test). When all bits are set to 0 (null set), it automatically passes.
			IpCount (number): The number of routers in the destination range.
			IpStart (str): The IP address of the first destination router.
			LabelRecordingDesired (bool): If enabled, indicates that label information is to be included when doing a route record.
			LocalProtectionDesired (bool): (Enabled by default) This permits transit routers to use a local traffic rerouting repair mechanism in the event of a fault on an adjacent downstream link or node. This may result in a violation of the explicit route object.
			LspIdCount (number): The number of LSP IDs in the range.
			LspIdStart (number): The first label-switched path ID (LSP ID) value in the range of LSP IDs.
			MaximumPacketSize (number): 32-bit integer. The maximum number of bytes allowed to cross the interface in a transmitted packet.
			MinimumPolicedUnit (number): 32-bit integer. The minimum allowable size for a policed unit.
			NodeProtectionDesired (bool): For Fast Reroute - if enabled, sets the Node Protection Desired Flag in the Session_Attribute object of the RRO message. It indicates to PLRs associated with the protected LSP path, that a backup path is desired that bypasses (avoids) at least the next node on the LSP.
			PathTearTlv (list(dict(arg1:number,arg2:number,arg3:str))): A set of custom TLVs to be included in TEAR messages, constructed with the rsvpCustomTlv command.
			PathTlv (list(dict(arg1:number,arg2:number,arg3:str))): A set of custom TLVs to be included in PATH messages, constructed with the rsvpCustomTlv command.
			PeakDataRate (number): The maximum traffic rate that can be maintained. The policing mechanism allows some burstiness, but restricts it so the overall packet transmission rate is less than the rate at which tokens.
			ReEvaluationRequestInterval (number): Represents the time period (in milliseconds) at which the path re-evaluation request is sent by the head LSR. The default value is: 180000 ms (3 mins).
			RefreshInterval (number): The interval between summary refresh messages.
			SeStyleDesired (bool): This indicates that the tunnel ingress node may reroute this tunnel without tearing it down. A tunnel egress node should use the SE Style when responding with an RESV message.
			SessionName (str): If enableAutoSessionName is not set, this is the name assigned to this session.
			SetupPriority (number): This is the session priority with respect to taking resources, such as preempting another session. The valid range is from 0 to 7. The highest priority is indicated by 0.
			TimeoutMultiplier (number): The number of Hellos before a neighbor is declared dead.
			TokenBucketRate (number): The rate of transfer for data in a flow. In this application, it is used with a traffic policing mechanism. The data tokens enter the bucket, filling the bucket. The data from a number of tokens is combined to form and send a packet. The goal is to determine a rate which will not overflow the specified token bucket size, and cause new data (tokens) to be rejected/discarded.
			TokenBucketSize (number): The maximum capacity (in bytes) the token bucket can hold, and above which newly received tokens cannot be processed and are discarded.

		Returns:
			self: This instance with matching senderRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of senderRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the senderRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def DoMakeBeforeBreak(self):
		"""Executes the doMakeBeforeBreak operation on the server.

		NOT DEFINED

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('doMakeBeforeBreak', payload=payload, response_object=None)

	def SendReEvaluationRequest(self):
		"""Executes the sendReEvaluationRequest operation on the server.

		NOT DEFINED

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendReEvaluationRequest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class BgpEpePeerSetList(Base):
	"""The BgpEpePeerSetList class encapsulates a system managed bgpEpePeerSetList node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the BgpEpePeerSetList property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'bgpEpePeerSetList'

	def __init__(self, parent):
		super(BgpEpePeerSetList, self).__init__(parent)

	@property
	def BBit(self):
		"""B-Flag:Backup Flag.If set, the SID refers to a path that is eligible for protection.

		Returns:
			bool
		"""
		return self._get_attribute('bBit')
	@BBit.setter
	def BBit(self, value):
		self._set_attribute('bBit', value)

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def LBit(self):
		"""L-Flag: Local Flag. If set, then the value/index carried by the SID has local significance.

		Returns:
			bool
		"""
		return self._get_attribute('lBit')
	@LBit.setter
	def LBit(self, value):
		self._set_attribute('lBit', value)

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def PBit(self):
		"""P-Flag: Persistent Flag: If set, the SID is persistently allocated, i.e. the SID value remains consistent across router restart and session/interface flap

		Returns:
			bool
		"""
		return self._get_attribute('pBit')
	@PBit.setter
	def PBit(self, value):
		self._set_attribute('pBit', value)

	@property
	def Reserved(self):
		"""Reserved

		Returns:
			number
		"""
		return self._get_attribute('reserved')
	@Reserved.setter
	def Reserved(self, value):
		self._set_attribute('reserved', value)

	@property
	def RsvdBits(self):
		"""Reserved for future use and MUST be zero when originated and ignored when received

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rsvdBits')

	@property
	def SidIndex(self):
		"""Local Label for Peer-Set

		Returns:
			str(index|sid)
		"""
		return self._get_attribute('sidIndex')
	@SidIndex.setter
	def SidIndex(self, value):
		self._set_attribute('sidIndex', value)

	@property
	def SidIndexValue(self):
		"""If Local Label type is SID, max value is 16777215 and for Index max value is 4294967295

		Returns:
			number
		"""
		return self._get_attribute('sidIndexValue')
	@SidIndexValue.setter
	def SidIndexValue(self, value):
		self._set_attribute('sidIndexValue', value)

	@property
	def VBit(self):
		"""V-Flag: Value flag. If set, then the SID carries a label value.

		Returns:
			bool
		"""
		return self._get_attribute('vBit')
	@VBit.setter
	def VBit(self, value):
		self._set_attribute('vBit', value)

	@property
	def Weight(self):
		"""Weight of SID for the purpose of load balancing

		Returns:
			number
		"""
		return self._get_attribute('weight')
	@Weight.setter
	def Weight(self, value):
		self._set_attribute('weight', value)

	def update(self, BBit=None, LBit=None, Name=None, PBit=None, Reserved=None, SidIndex=None, SidIndexValue=None, VBit=None, Weight=None):
		"""Updates a child instance of bgpEpePeerSetList on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			BBit (bool): B-Flag:Backup Flag.If set, the SID refers to a path that is eligible for protection.
			LBit (bool): L-Flag: Local Flag. If set, then the value/index carried by the SID has local significance.
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			PBit (bool): P-Flag: Persistent Flag: If set, the SID is persistently allocated, i.e. the SID value remains consistent across router restart and session/interface flap
			Reserved (number): Reserved
			SidIndex (str(index|sid)): Local Label for Peer-Set
			SidIndexValue (number): If Local Label type is SID, max value is 16777215 and for Index max value is 4294967295
			VBit (bool): V-Flag: Value flag. If set, then the SID carries a label value.
			Weight (number): Weight of SID for the purpose of load balancing

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, BBit=None, Count=None, DescriptiveName=None, LBit=None, Name=None, PBit=None, Reserved=None, SidIndex=None, SidIndexValue=None, VBit=None, Weight=None):
		"""Finds and retrieves bgpEpePeerSetList data from the server.

		All named parameters support regex and can be used to selectively retrieve bgpEpePeerSetList data from the server.
		By default the find method takes no parameters and will retrieve all bgpEpePeerSetList data from the server.

		Args:
			BBit (bool): B-Flag:Backup Flag.If set, the SID refers to a path that is eligible for protection.
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			LBit (bool): L-Flag: Local Flag. If set, then the value/index carried by the SID has local significance.
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			PBit (bool): P-Flag: Persistent Flag: If set, the SID is persistently allocated, i.e. the SID value remains consistent across router restart and session/interface flap
			Reserved (number): Reserved
			SidIndex (str(index|sid)): Local Label for Peer-Set
			SidIndexValue (number): If Local Label type is SID, max value is 16777215 and for Index max value is 4294967295
			VBit (bool): V-Flag: Value flag. If set, then the SID carries a label value.
			Weight (number): Weight of SID for the purpose of load balancing

		Returns:
			self: This instance with matching bgpEpePeerSetList data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of bgpEpePeerSetList data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the bgpEpePeerSetList data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, RsvdBits=None):
		"""Base class infrastructure that gets a list of bgpEpePeerSetList device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			RsvdBits (str): optional regex of rsvdBits

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Capabilities(Base):
	"""The Capabilities class encapsulates a required capabilities node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Capabilities property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'capabilities'

	def __init__(self, parent):
		super(Capabilities, self).__init__(parent)

	@property
	def AdVpls(self):
		"""If true, enables the BGP autodiscovery VPLS tunnels.

		Returns:
			bool
		"""
		return self._get_attribute('adVpls')
	@AdVpls.setter
	def AdVpls(self, value):
		self._set_attribute('adVpls', value)

	@property
	def Evpn(self):
		"""If enabled, then this BGP peer range supports BGP MPLS Based Ethernet VPN per draft-ietf-l2vpn-evpn-03. Default value is false.

		Returns:
			bool
		"""
		return self._get_attribute('evpn')
	@Evpn.setter
	def Evpn(self, value):
		self._set_attribute('evpn', value)

	@property
	def FetchDetailedIpV4UnicastInfo(self):
		"""If enabled, this BGP router displays complete information about the Ipv4UnicastInfo.

		Returns:
			bool
		"""
		return self._get_attribute('fetchDetailedIpV4UnicastInfo')
	@FetchDetailedIpV4UnicastInfo.setter
	def FetchDetailedIpV4UnicastInfo(self, value):
		self._set_attribute('fetchDetailedIpV4UnicastInfo', value)

	@property
	def FetchDetailedIpV6UnicastInfo(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('fetchDetailedIpV6UnicastInfo')
	@FetchDetailedIpV6UnicastInfo.setter
	def FetchDetailedIpV6UnicastInfo(self, value):
		self._set_attribute('fetchDetailedIpV6UnicastInfo', value)

	@property
	def IpV4Mpls(self):
		"""If true, learns IPv4 MPLS routes.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4Mpls')
	@IpV4Mpls.setter
	def IpV4Mpls(self, value):
		self._set_attribute('ipV4Mpls', value)

	@property
	def IpV4MplsVpn(self):
		"""If true, learns MPLS VPN routes.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4MplsVpn')
	@IpV4MplsVpn.setter
	def IpV4MplsVpn(self, value):
		self._set_attribute('ipV4MplsVpn', value)

	@property
	def IpV4Multicast(self):
		"""If true, learns IPv4 Multicast routes.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4Multicast')
	@IpV4Multicast.setter
	def IpV4Multicast(self, value):
		self._set_attribute('ipV4Multicast', value)

	@property
	def IpV4MulticastMplsVpn(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('ipV4MulticastMplsVpn')
	@IpV4MulticastMplsVpn.setter
	def IpV4MulticastMplsVpn(self, value):
		self._set_attribute('ipV4MulticastMplsVpn', value)

	@property
	def IpV4MulticastVpn(self):
		"""If enabled, this BGP router/peer supports the IPv4 Multicast/VPN address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4MulticastVpn')
	@IpV4MulticastVpn.setter
	def IpV4MulticastVpn(self, value):
		self._set_attribute('ipV4MulticastVpn', value)

	@property
	def IpV4Unicast(self):
		"""If true, learns IPv4 Unicast routes.

		Returns:
			bool
		"""
		return self._get_attribute('ipV4Unicast')
	@IpV4Unicast.setter
	def IpV4Unicast(self, value):
		self._set_attribute('ipV4Unicast', value)

	@property
	def IpV6Mpls(self):
		"""If true, learns IPv6 MPLS routes.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6Mpls')
	@IpV6Mpls.setter
	def IpV6Mpls(self, value):
		self._set_attribute('ipV6Mpls', value)

	@property
	def IpV6MplsVpn(self):
		"""If true, learns IPv6 MPLS VPN routes.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6MplsVpn')
	@IpV6MplsVpn.setter
	def IpV6MplsVpn(self, value):
		self._set_attribute('ipV6MplsVpn', value)

	@property
	def IpV6Multicast(self):
		"""If true, learns IPv6 Multicast routes.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6Multicast')
	@IpV6Multicast.setter
	def IpV6Multicast(self, value):
		self._set_attribute('ipV6Multicast', value)

	@property
	def IpV6MulticastMplsVpn(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('ipV6MulticastMplsVpn')
	@IpV6MulticastMplsVpn.setter
	def IpV6MulticastMplsVpn(self, value):
		self._set_attribute('ipV6MulticastMplsVpn', value)

	@property
	def IpV6MulticastVpn(self):
		"""If enabled, this BGP router/peer supports the IPv6 Multicast/VPN address family.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6MulticastVpn')
	@IpV6MulticastVpn.setter
	def IpV6MulticastVpn(self, value):
		self._set_attribute('ipV6MulticastVpn', value)

	@property
	def IpV6Unicast(self):
		"""If true, learns IPv6 Unicast routes.

		Returns:
			bool
		"""
		return self._get_attribute('ipV6Unicast')
	@IpV6Unicast.setter
	def IpV6Unicast(self, value):
		self._set_attribute('ipV6Unicast', value)

	@property
	def Vpls(self):
		"""If true, learns VPLS routes.

		Returns:
			bool
		"""
		return self._get_attribute('vpls')
	@Vpls.setter
	def Vpls(self, value):
		self._set_attribute('vpls', value)

	def update(self, AdVpls=None, Evpn=None, FetchDetailedIpV4UnicastInfo=None, FetchDetailedIpV6UnicastInfo=None, IpV4Mpls=None, IpV4MplsVpn=None, IpV4Multicast=None, IpV4MulticastMplsVpn=None, IpV4MulticastVpn=None, IpV4Unicast=None, IpV6Mpls=None, IpV6MplsVpn=None, IpV6Multicast=None, IpV6MulticastMplsVpn=None, IpV6MulticastVpn=None, IpV6Unicast=None, Vpls=None):
		"""Updates a child instance of capabilities on the server.

		Args:
			AdVpls (bool): If true, enables the BGP autodiscovery VPLS tunnels.
			Evpn (bool): If enabled, then this BGP peer range supports BGP MPLS Based Ethernet VPN per draft-ietf-l2vpn-evpn-03. Default value is false.
			FetchDetailedIpV4UnicastInfo (bool): If enabled, this BGP router displays complete information about the Ipv4UnicastInfo.
			FetchDetailedIpV6UnicastInfo (bool): NOT DEFINED
			IpV4Mpls (bool): If true, learns IPv4 MPLS routes.
			IpV4MplsVpn (bool): If true, learns MPLS VPN routes.
			IpV4Multicast (bool): If true, learns IPv4 Multicast routes.
			IpV4MulticastMplsVpn (bool): NOT DEFINED
			IpV4MulticastVpn (bool): If enabled, this BGP router/peer supports the IPv4 Multicast/VPN address family.
			IpV4Unicast (bool): If true, learns IPv4 Unicast routes.
			IpV6Mpls (bool): If true, learns IPv6 MPLS routes.
			IpV6MplsVpn (bool): If true, learns IPv6 MPLS VPN routes.
			IpV6Multicast (bool): If true, learns IPv6 Multicast routes.
			IpV6MulticastMplsVpn (bool): NOT DEFINED
			IpV6MulticastVpn (bool): If enabled, this BGP router/peer supports the IPv6 Multicast/VPN address family.
			IpV6Unicast (bool): If true, learns IPv6 Unicast routes.
			Vpls (bool): If true, learns VPLS routes.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class OfChannelPortsSwitchLearnedInfo(Base):
	"""The OfChannelPortsSwitchLearnedInfo class encapsulates a system managed ofChannelPortsSwitchLearnedInfo node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the OfChannelPortsSwitchLearnedInfo property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'ofChannelPortsSwitchLearnedInfo'

	def __init__(self, parent):
		super(OfChannelPortsSwitchLearnedInfo, self).__init__(parent)

	@property
	def AdvertisedFeatures(self):
		"""This describes the advertised features of the physical port.

		Returns:
			str
		"""
		return self._get_attribute('advertisedFeatures')

	@property
	def Config(self):
		"""This describes the current configuration of the physical port.

		Returns:
			str
		"""
		return self._get_attribute('config')

	@property
	def CurrentFeatures(self):
		"""This describes the current features of the physical port.

		Returns:
			str
		"""
		return self._get_attribute('currentFeatures')

	@property
	def CurrentSpeed(self):
		"""This describes the current speed of the port.

		Returns:
			number
		"""
		return self._get_attribute('currentSpeed')

	@property
	def DataPathId(self):
		"""This describes the datapath ID of the switch.

		Returns:
			str
		"""
		return self._get_attribute('dataPathId')

	@property
	def DataPathIdAsHex(self):
		"""This describes the datapath ID, in hexadecimal format, of the switch.

		Returns:
			str
		"""
		return self._get_attribute('dataPathIdAsHex')

	@property
	def EthernetAddress(self):
		"""This describes the hardware address of the physical port.

		Returns:
			str
		"""
		return self._get_attribute('ethernetAddress')

	@property
	def LocalIp(self):
		"""This describes the local IP of the switch.

		Returns:
			str
		"""
		return self._get_attribute('localIp')

	@property
	def MaximumSpeed(self):
		"""This describes the maximum speed of the port.

		Returns:
			number
		"""
		return self._get_attribute('maximumSpeed')

	@property
	def Name(self):
		"""This describes the name of the physical port.

		Returns:
			str
		"""
		return self._get_attribute('name')

	@property
	def PeerAdvertisedFeatures(self):
		"""This describes the peer advertised features of the physical port.

		Returns:
			str
		"""
		return self._get_attribute('peerAdvertisedFeatures')

	@property
	def PortNumber(self):
		"""This describes the port number of the physical port.

		Returns:
			number
		"""
		return self._get_attribute('portNumber')

	@property
	def RemoteIp(self):
		"""This describes the IP address of the remote end of the OF channel.

		Returns:
			str
		"""
		return self._get_attribute('remoteIp')

	@property
	def State(self):
		"""This describes the current state of the physical port.

		Returns:
			str
		"""
		return self._get_attribute('state')

	@property
	def SupportedFeatures(self):
		"""This describes the supported features of the physical port.

		Returns:
			str
		"""
		return self._get_attribute('supportedFeatures')

	def find(self, AdvertisedFeatures=None, Config=None, CurrentFeatures=None, CurrentSpeed=None, DataPathId=None, DataPathIdAsHex=None, EthernetAddress=None, LocalIp=None, MaximumSpeed=None, Name=None, PeerAdvertisedFeatures=None, PortNumber=None, RemoteIp=None, State=None, SupportedFeatures=None):
		"""Finds and retrieves ofChannelPortsSwitchLearnedInfo data from the server.

		All named parameters support regex and can be used to selectively retrieve ofChannelPortsSwitchLearnedInfo data from the server.
		By default the find method takes no parameters and will retrieve all ofChannelPortsSwitchLearnedInfo data from the server.

		Args:
			AdvertisedFeatures (str): This describes the advertised features of the physical port.
			Config (str): This describes the current configuration of the physical port.
			CurrentFeatures (str): This describes the current features of the physical port.
			CurrentSpeed (number): This describes the current speed of the port.
			DataPathId (str): This describes the datapath ID of the switch.
			DataPathIdAsHex (str): This describes the datapath ID, in hexadecimal format, of the switch.
			EthernetAddress (str): This describes the hardware address of the physical port.
			LocalIp (str): This describes the local IP of the switch.
			MaximumSpeed (number): This describes the maximum speed of the port.
			Name (str): This describes the name of the physical port.
			PeerAdvertisedFeatures (str): This describes the peer advertised features of the physical port.
			PortNumber (number): This describes the port number of the physical port.
			RemoteIp (str): This describes the IP address of the remote end of the OF channel.
			State (str): This describes the current state of the physical port.
			SupportedFeatures (str): This describes the supported features of the physical port.

		Returns:
			self: This instance with matching ofChannelPortsSwitchLearnedInfo data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of ofChannelPortsSwitchLearnedInfo data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the ofChannelPortsSwitchLearnedInfo data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Nssa(Base):
	"""The Nssa class encapsulates a system managed nssa node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Nssa property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'nssa'

	def __init__(self, parent):
		super(Nssa, self).__init__(parent)

	@property
	def EBit(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('eBit')
	@EBit.setter
	def EBit(self, value):
		self._set_attribute('eBit', value)

	@property
	def ForwardingAddress(self):
		"""

		Returns:
			str
		"""
		return self._get_attribute('forwardingAddress')
	@ForwardingAddress.setter
	def ForwardingAddress(self, value):
		self._set_attribute('forwardingAddress', value)

	@property
	def IncrementLinkStateIdBy(self):
		"""

		Returns:
			str
		"""
		return self._get_attribute('incrementLinkStateIdBy')
	@IncrementLinkStateIdBy.setter
	def IncrementLinkStateIdBy(self, value):
		self._set_attribute('incrementLinkStateIdBy', value)

	@property
	def Metric(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('metric')
	@Metric.setter
	def Metric(self, value):
		self._set_attribute('metric', value)

	@property
	def NetworkMask(self):
		"""

		Returns:
			str
		"""
		return self._get_attribute('networkMask')
	@NetworkMask.setter
	def NetworkMask(self, value):
		self._set_attribute('networkMask', value)

	@property
	def NumberOfLsa(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('numberOfLsa')
	@NumberOfLsa.setter
	def NumberOfLsa(self, value):
		self._set_attribute('numberOfLsa', value)

	@property
	def RouteTag(self):
		"""

		Returns:
			str
		"""
		return self._get_attribute('routeTag')
	@RouteTag.setter
	def RouteTag(self, value):
		self._set_attribute('routeTag', value)

	def update(self, EBit=None, ForwardingAddress=None, IncrementLinkStateIdBy=None, Metric=None, NetworkMask=None, NumberOfLsa=None, RouteTag=None):
		"""Updates a child instance of nssa on the server.

		Args:
			EBit (bool): 
			ForwardingAddress (str): 
			IncrementLinkStateIdBy (str): 
			Metric (number): 
			NetworkMask (str): 
			NumberOfLsa (number): 
			RouteTag (str): 

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, EBit=None, ForwardingAddress=None, IncrementLinkStateIdBy=None, Metric=None, NetworkMask=None, NumberOfLsa=None, RouteTag=None):
		"""Finds and retrieves nssa data from the server.

		All named parameters support regex and can be used to selectively retrieve nssa data from the server.
		By default the find method takes no parameters and will retrieve all nssa data from the server.

		Args:
			EBit (bool): 
			ForwardingAddress (str): 
			IncrementLinkStateIdBy (str): 
			Metric (number): 
			NetworkMask (str): 
			NumberOfLsa (number): 
			RouteTag (str): 

		Returns:
			self: This instance with matching nssa data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of nssa data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the nssa data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def BurstSize(self):
		"""The number of packets to send in a burst.

		Returns:
			number
		"""
		return self._get_attribute('burstSize')
	@BurstSize.setter
	def BurstSize(self, value):
		self._set_attribute('burstSize', value)

	@property
	def CalculateJitter(self):
		"""If true, the jitter is calculated.

		Returns:
			bool
		"""
		return self._get_attribute('calculateJitter')
	@CalculateJitter.setter
	def CalculateJitter(self, value):
		self._set_attribute('calculateJitter', value)

	@property
	def CalculateLatency(self):
		"""If true, calculates the latency.

		Returns:
			bool
		"""
		return self._get_attribute('calculateLatency')
	@CalculateLatency.setter
	def CalculateLatency(self, value):
		self._set_attribute('calculateLatency', value)

	@property
	def CalibrateLatency(self):
		"""If true, calibrates the latency.

		Returns:
			bool
		"""
		return self._get_attribute('calibrateLatency')
	@CalibrateLatency.setter
	def CalibrateLatency(self, value):
		self._set_attribute('calibrateLatency', value)

	@property
	def CountRandomFrameSize(self):
		"""If true, randomly counts the frame size.

		Returns:
			number
		"""
		return self._get_attribute('countRandomFrameSize')
	@CountRandomFrameSize.setter
	def CountRandomFrameSize(self, value):
		self._set_attribute('countRandomFrameSize', value)

	@property
	def CountRandomIpRatio(self):
		"""Sets the count of the random ip ratio loop

		Returns:
			number
		"""
		return self._get_attribute('countRandomIpRatio')
	@CountRandomIpRatio.setter
	def CountRandomIpRatio(self, value):
		self._set_attribute('countRandomIpRatio', value)

	@property
	def CountRandomLoadRate(self):
		"""The random count of the load rate.

		Returns:
			number
		"""
		return self._get_attribute('countRandomLoadRate')
	@CountRandomLoadRate.setter
	def CountRandomLoadRate(self, value):
		self._set_attribute('countRandomLoadRate', value)

	@property
	def CustomLoadUnit(self):
		"""Specifies the custom load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('customLoadUnit')
	@CustomLoadUnit.setter
	def CustomLoadUnit(self, value):
		self._set_attribute('customLoadUnit', value)

	@property
	def DelayAfterTransmit(self):
		"""Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('delayAfterTransmit')
	@DelayAfterTransmit.setter
	def DelayAfterTransmit(self, value):
		self._set_attribute('delayAfterTransmit', value)

	@property
	def DetailedResultsEnabled(self):
		"""If true, it enables the detailed results for the fully meshed case

		Returns:
			bool
		"""
		return self._get_attribute('detailedResultsEnabled')
	@DetailedResultsEnabled.setter
	def DetailedResultsEnabled(self, value):
		self._set_attribute('detailedResultsEnabled', value)

	@property
	def Duration(self):
		"""The duration of the test in hours, which is used to calculate the number of frames to transmit.

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def EnableDataIntegrity(self):
		"""If true, enables the checking of data integrity for the pass or fail of the trial.

		Returns:
			bool
		"""
		return self._get_attribute('enableDataIntegrity')
	@EnableDataIntegrity.setter
	def EnableDataIntegrity(self, value):
		self._set_attribute('enableDataIntegrity', value)

	@property
	def EnableLayer1Rate(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLayer1Rate')
	@EnableLayer1Rate.setter
	def EnableLayer1Rate(self, value):
		self._set_attribute('enableLayer1Rate', value)

	@property
	def EnableMinFrameSize(self):
		"""If true, enables minimum frame size.

		Returns:
			bool
		"""
		return self._get_attribute('enableMinFrameSize')
	@EnableMinFrameSize.setter
	def EnableMinFrameSize(self, value):
		self._set_attribute('enableMinFrameSize', value)

	@property
	def EnableOldStatsForReef(self):
		"""If true, enables old statistics for reef load module.

		Returns:
			bool
		"""
		return self._get_attribute('enableOldStatsForReef')
	@EnableOldStatsForReef.setter
	def EnableOldStatsForReef(self, value):
		self._set_attribute('enableOldStatsForReef', value)

	@property
	def FloodedFramesEnabled(self):
		"""If true, it enables the flooded frames statistics

		Returns:
			bool
		"""
		return self._get_attribute('floodedFramesEnabled')
	@FloodedFramesEnabled.setter
	def FloodedFramesEnabled(self, value):
		self._set_attribute('floodedFramesEnabled', value)

	@property
	def ForceRegenerate(self):
		"""Initiates a forced regeneration.

		Returns:
			bool
		"""
		return self._get_attribute('forceRegenerate')
	@ForceRegenerate.setter
	def ForceRegenerate(self, value):
		self._set_attribute('forceRegenerate', value)

	@property
	def FrameSizeMode(self):
		"""This attribute is the frame size mode for the Quad Gaussian.

		Returns:
			str(custom|increment|random|unchanged)
		"""
		return self._get_attribute('frameSizeMode')
	@FrameSizeMode.setter
	def FrameSizeMode(self, value):
		self._set_attribute('frameSizeMode', value)

	@property
	def FramesPerBurstGap(self):
		"""The number of frames to be sent after each burst.

		Returns:
			number
		"""
		return self._get_attribute('framesPerBurstGap')
	@FramesPerBurstGap.setter
	def FramesPerBurstGap(self, value):
		self._set_attribute('framesPerBurstGap', value)

	@property
	def Framesize(self):
		"""The frame size to be used.

		Returns:
			str
		"""
		return self._get_attribute('framesize')
	@Framesize.setter
	def Framesize(self, value):
		self._set_attribute('framesize', value)

	@property
	def FramesizeImixList(self):
		"""The list of the available lmix frame sizes.

		Returns:
			str
		"""
		return self._get_attribute('framesizeImixList')
	@FramesizeImixList.setter
	def FramesizeImixList(self, value):
		self._set_attribute('framesizeImixList', value)

	@property
	def FramesizeList(self):
		"""The list of the available frame sizes.

		Returns:
			list(str)
		"""
		return self._get_attribute('framesizeList')
	@FramesizeList.setter
	def FramesizeList(self, value):
		self._set_attribute('framesizeList', value)

	@property
	def Gap(self):
		"""The gap in transmission of frames.

		Returns:
			number
		"""
		return self._get_attribute('gap')
	@Gap.setter
	def Gap(self, value):
		self._set_attribute('gap', value)

	@property
	def GenerateTrackingOptionAggregationFiles(self):
		"""If true, enables the tracking option in aggregation files.

		Returns:
			bool
		"""
		return self._get_attribute('generateTrackingOptionAggregationFiles')
	@GenerateTrackingOptionAggregationFiles.setter
	def GenerateTrackingOptionAggregationFiles(self, value):
		self._set_attribute('generateTrackingOptionAggregationFiles', value)

	@property
	def Grain(self):
		"""The granular value of the test parameter.

		Returns:
			str(coarse|fine)
		"""
		return self._get_attribute('grain')
	@Grain.setter
	def Grain(self, value):
		self._set_attribute('grain', value)

	@property
	def ImixAdd(self):
		"""Adds an imix data.

		Returns:
			str
		"""
		return self._get_attribute('imixAdd')
	@ImixAdd.setter
	def ImixAdd(self, value):
		self._set_attribute('imixAdd', value)

	@property
	def ImixData(self):
		"""Displays imix data.

		Returns:
			str
		"""
		return self._get_attribute('imixData')
	@ImixData.setter
	def ImixData(self, value):
		self._set_attribute('imixData', value)

	@property
	def ImixDelete(self):
		"""Deletes an imix data.

		Returns:
			str
		"""
		return self._get_attribute('imixDelete')
	@ImixDelete.setter
	def ImixDelete(self, value):
		self._set_attribute('imixDelete', value)

	@property
	def ImixDistribution(self):
		"""Shows the distribution of imix data.

		Returns:
			str(bwpercentage|weight)
		"""
		return self._get_attribute('imixDistribution')
	@ImixDistribution.setter
	def ImixDistribution(self, value):
		self._set_attribute('imixDistribution', value)

	@property
	def ImixEnabled(self):
		"""If True, Enables the imix value.

		Returns:
			bool
		"""
		return self._get_attribute('imixEnabled')
	@ImixEnabled.setter
	def ImixEnabled(self, value):
		self._set_attribute('imixEnabled', value)

	@property
	def ImixTemplates(self):
		"""Specefies the imix templates.

		Returns:
			str(cisco|imix|ipsec|ipv6|none|quadmodal|standard|tcp|tolly|trimodal)
		"""
		return self._get_attribute('imixTemplates')
	@ImixTemplates.setter
	def ImixTemplates(self, value):
		self._set_attribute('imixTemplates', value)

	@property
	def ImixTrafficType(self):
		"""Displays the imix traffic type.

		Returns:
			str
		"""
		return self._get_attribute('imixTrafficType')
	@ImixTrafficType.setter
	def ImixTrafficType(self, value):
		self._set_attribute('imixTrafficType', value)

	@property
	def IncrementLoadUnit(self):
		"""The unit increment for the load.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('incrementLoadUnit')
	@IncrementLoadUnit.setter
	def IncrementLoadUnit(self, value):
		self._set_attribute('incrementLoadUnit', value)

	@property
	def InitialIncrementLoadRate(self):
		"""The initial incremental value of the load rate.

		Returns:
			number
		"""
		return self._get_attribute('initialIncrementLoadRate')
	@InitialIncrementLoadRate.setter
	def InitialIncrementLoadRate(self, value):
		self._set_attribute('initialIncrementLoadRate', value)

	@property
	def InitialStepLoadRate(self):
		"""The initial step value of the load rate.

		Returns:
			number
		"""
		return self._get_attribute('initialStepLoadRate')
	@InitialStepLoadRate.setter
	def InitialStepLoadRate(self, value):
		self._set_attribute('initialStepLoadRate', value)

	@property
	def IpRatioMode(self):
		"""Sets the ip ratio mode

		Returns:
			str(custom|fixed|increment|random)
		"""
		return self._get_attribute('ipRatioMode')
	@IpRatioMode.setter
	def IpRatioMode(self, value):
		self._set_attribute('ipRatioMode', value)

	@property
	def Ipv4RatioList(self):
		"""Sets the ipv4 ratio list

		Returns:
			str
		"""
		return self._get_attribute('ipv4RatioList')
	@Ipv4RatioList.setter
	def Ipv4RatioList(self, value):
		self._set_attribute('ipv4RatioList', value)

	@property
	def Ipv4rate(self):
		"""The rate at which IPv4 traffic is sent.

		Returns:
			number
		"""
		return self._get_attribute('ipv4rate')
	@Ipv4rate.setter
	def Ipv4rate(self, value):
		self._set_attribute('ipv4rate', value)

	@property
	def Ipv6RatioList(self):
		"""Sets the ipv6 ratio list

		Returns:
			str
		"""
		return self._get_attribute('ipv6RatioList')
	@Ipv6RatioList.setter
	def Ipv6RatioList(self, value):
		self._set_attribute('ipv6RatioList', value)

	@property
	def Ipv6rate(self):
		"""The rate at which IPv6 traffic is sent.

		Returns:
			number
		"""
		return self._get_attribute('ipv6rate')
	@Ipv6rate.setter
	def Ipv6rate(self, value):
		self._set_attribute('ipv6rate', value)

	@property
	def LatencyBins(self):
		"""DEPRECATED Sets the latency bins statistics.

		Returns:
			str
		"""
		return self._get_attribute('latencyBins')
	@LatencyBins.setter
	def LatencyBins(self, value):
		self._set_attribute('latencyBins', value)

	@property
	def LatencyBinsEnabled(self):
		"""DEPRECATED Enables the latency bins statistics.

		Returns:
			bool
		"""
		return self._get_attribute('latencyBinsEnabled')
	@LatencyBinsEnabled.setter
	def LatencyBinsEnabled(self, value):
		self._set_attribute('latencyBinsEnabled', value)

	@property
	def LatencyType(self):
		"""DEPRECATED The type of latency.

		Returns:
			str(cutThrough|forwardingDelay|mef|storeForward)
		"""
		return self._get_attribute('latencyType')
	@LatencyType.setter
	def LatencyType(self, value):
		self._set_attribute('latencyType', value)

	@property
	def LoadRateList(self):
		"""DEPRECATED Enters the Load Rate List.

		Returns:
			str
		"""
		return self._get_attribute('loadRateList')
	@LoadRateList.setter
	def LoadRateList(self, value):
		self._set_attribute('loadRateList', value)

	@property
	def LoadType(self):
		"""DEPRECATED The type of the payload setting.

		Returns:
			str(step)
		"""
		return self._get_attribute('loadType')
	@LoadType.setter
	def LoadType(self, value):
		self._set_attribute('loadType', value)

	@property
	def LoadUnit(self):
		"""DEPRECATED The load unit value.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('loadUnit')
	@LoadUnit.setter
	def LoadUnit(self, value):
		self._set_attribute('loadUnit', value)

	@property
	def MapType(self):
		"""DEPRECATED The mapping type.

		Returns:
			str
		"""
		return self._get_attribute('mapType')
	@MapType.setter
	def MapType(self, value):
		self._set_attribute('mapType', value)

	@property
	def MaxIncrementFrameSize(self):
		"""DEPRECATED The maximum incremental value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('maxIncrementFrameSize')
	@MaxIncrementFrameSize.setter
	def MaxIncrementFrameSize(self, value):
		self._set_attribute('maxIncrementFrameSize', value)

	@property
	def MaxIncrementIpv4Ratio(self):
		"""DEPRECATED Sets the maximum increment value for the ipv4 ratio

		Returns:
			str
		"""
		return self._get_attribute('maxIncrementIpv4Ratio')
	@MaxIncrementIpv4Ratio.setter
	def MaxIncrementIpv4Ratio(self, value):
		self._set_attribute('maxIncrementIpv4Ratio', value)

	@property
	def MaxIncrementIpv6Ratio(self):
		"""DEPRECATED Sets the maximum increment value for the ipv6 ratio

		Returns:
			str
		"""
		return self._get_attribute('maxIncrementIpv6Ratio')
	@MaxIncrementIpv6Ratio.setter
	def MaxIncrementIpv6Ratio(self, value):
		self._set_attribute('maxIncrementIpv6Ratio', value)

	@property
	def MaxIncrementLoadRate(self):
		"""DEPRECATED The maximum incremental value of the load rate.

		Returns:
			number
		"""
		return self._get_attribute('maxIncrementLoadRate')
	@MaxIncrementLoadRate.setter
	def MaxIncrementLoadRate(self, value):
		self._set_attribute('maxIncrementLoadRate', value)

	@property
	def MaxRandomFrameSize(self):
		"""DEPRECATED The maximum random frame size to be sent.

		Returns:
			number
		"""
		return self._get_attribute('maxRandomFrameSize')
	@MaxRandomFrameSize.setter
	def MaxRandomFrameSize(self, value):
		self._set_attribute('maxRandomFrameSize', value)

	@property
	def MaxRandomIpv4Ratio(self):
		"""DEPRECATED Sets the maximum radom value for the ipv4 ratio

		Returns:
			str
		"""
		return self._get_attribute('maxRandomIpv4Ratio')
	@MaxRandomIpv4Ratio.setter
	def MaxRandomIpv4Ratio(self, value):
		self._set_attribute('maxRandomIpv4Ratio', value)

	@property
	def MaxRandomIpv6Ratio(self):
		"""DEPRECATED Sets the maximum random value for the ipv6 ratio

		Returns:
			str
		"""
		return self._get_attribute('maxRandomIpv6Ratio')
	@MaxRandomIpv6Ratio.setter
	def MaxRandomIpv6Ratio(self, value):
		self._set_attribute('maxRandomIpv6Ratio', value)

	@property
	def MaxRandomLoadRate(self):
		"""DEPRECATED The maximum random value of the load rate.

		Returns:
			number
		"""
		return self._get_attribute('maxRandomLoadRate')
	@MaxRandomLoadRate.setter
	def MaxRandomLoadRate(self, value):
		self._set_attribute('maxRandomLoadRate', value)

	@property
	def MaxStepLoadRate(self):
		"""DEPRECATED The maximum step value of the load rate.

		Returns:
			number
		"""
		return self._get_attribute('maxStepLoadRate')
	@MaxStepLoadRate.setter
	def MaxStepLoadRate(self, value):
		self._set_attribute('maxStepLoadRate', value)

	@property
	def MinFpsRate(self):
		"""DEPRECATED The rate at which minimum frames are sent per second.

		Returns:
			number
		"""
		return self._get_attribute('minFpsRate')
	@MinFpsRate.setter
	def MinFpsRate(self, value):
		self._set_attribute('minFpsRate', value)

	@property
	def MinIncrementFrameSize(self):
		"""DEPRECATED The minimum incremental value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('minIncrementFrameSize')
	@MinIncrementFrameSize.setter
	def MinIncrementFrameSize(self, value):
		self._set_attribute('minIncrementFrameSize', value)

	@property
	def MinIncrementIpv4Ratio(self):
		"""DEPRECATED Sets the minimum increment value for the ipv4 ratio

		Returns:
			str
		"""
		return self._get_attribute('minIncrementIpv4Ratio')
	@MinIncrementIpv4Ratio.setter
	def MinIncrementIpv4Ratio(self, value):
		self._set_attribute('minIncrementIpv4Ratio', value)

	@property
	def MinIncrementIpv6Ratio(self):
		"""DEPRECATED Sets the minimum increment value for the ipv6 ratio

		Returns:
			str
		"""
		return self._get_attribute('minIncrementIpv6Ratio')
	@MinIncrementIpv6Ratio.setter
	def MinIncrementIpv6Ratio(self, value):
		self._set_attribute('minIncrementIpv6Ratio', value)

	@property
	def MinKbpsRate(self):
		"""DEPRECATED The rate at which minimum frames are sent per kbps.

		Returns:
			number
		"""
		return self._get_attribute('minKbpsRate')
	@MinKbpsRate.setter
	def MinKbpsRate(self, value):
		self._set_attribute('minKbpsRate', value)

	@property
	def MinRandomFrameSize(self):
		"""DEPRECATED The minimum random frame size to be sent.

		Returns:
			number
		"""
		return self._get_attribute('minRandomFrameSize')
	@MinRandomFrameSize.setter
	def MinRandomFrameSize(self, value):
		self._set_attribute('minRandomFrameSize', value)

	@property
	def MinRandomIpv4Ratio(self):
		"""DEPRECATED Sets the minimum random value for the ipv4 ratio

		Returns:
			str
		"""
		return self._get_attribute('minRandomIpv4Ratio')
	@MinRandomIpv4Ratio.setter
	def MinRandomIpv4Ratio(self, value):
		self._set_attribute('minRandomIpv4Ratio', value)

	@property
	def MinRandomIpv6Ratio(self):
		"""DEPRECATED Sets the minimum random value for the ipv6 ratio

		Returns:
			str
		"""
		return self._get_attribute('minRandomIpv6Ratio')
	@MinRandomIpv6Ratio.setter
	def MinRandomIpv6Ratio(self, value):
		self._set_attribute('minRandomIpv6Ratio', value)

	@property
	def MinRandomLoadRate(self):
		"""DEPRECATED The maximum random value of the load rate.

		Returns:
			number
		"""
		return self._get_attribute('minRandomLoadRate')
	@MinRandomLoadRate.setter
	def MinRandomLoadRate(self, value):
		self._set_attribute('minRandomLoadRate', value)

	@property
	def MinStepLoadRate(self):
		"""DEPRECATED The minimum step value of load rate.

		Returns:
			number
		"""
		return self._get_attribute('minStepLoadRate')
	@MinStepLoadRate.setter
	def MinStepLoadRate(self, value):
		self._set_attribute('minStepLoadRate', value)

	@property
	def NumFrames(self):
		"""DEPRECATED The number of frames sent.

		Returns:
			number
		"""
		return self._get_attribute('numFrames')
	@NumFrames.setter
	def NumFrames(self, value):
		self._set_attribute('numFrames', value)

	@property
	def Numtrials(self):
		"""DEPRECATED The integer value that states the number of trials permitted.

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def PeakLoadingReplicationCount(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('peakLoadingReplicationCount')
	@PeakLoadingReplicationCount.setter
	def PeakLoadingReplicationCount(self, value):
		self._set_attribute('peakLoadingReplicationCount', value)

	@property
	def PerTrafficResults(self):
		"""DEPRECATED 

		Returns:
			bool
		"""
		return self._get_attribute('perTrafficResults')
	@PerTrafficResults.setter
	def PerTrafficResults(self, value):
		self._set_attribute('perTrafficResults', value)

	@property
	def PercentMaxRate(self):
		"""DEPRECATED The maximum percentage rate.

		Returns:
			number
		"""
		return self._get_attribute('percentMaxRate')
	@PercentMaxRate.setter
	def PercentMaxRate(self, value):
		self._set_attribute('percentMaxRate', value)

	@property
	def PortDelayEnabled(self):
		"""DEPRECATED Enables the port delay.

		Returns:
			bool
		"""
		return self._get_attribute('portDelayEnabled')
	@PortDelayEnabled.setter
	def PortDelayEnabled(self, value):
		self._set_attribute('portDelayEnabled', value)

	@property
	def PortDelayUnit(self):
		"""DEPRECATED Sets the port delay unit in which it will be measured

		Returns:
			str(bytes|nanoseconds)
		"""
		return self._get_attribute('portDelayUnit')
	@PortDelayUnit.setter
	def PortDelayUnit(self, value):
		self._set_attribute('portDelayUnit', value)

	@property
	def PortDelayValue(self):
		"""DEPRECATED Sets the port delay value.

		Returns:
			number
		"""
		return self._get_attribute('portDelayValue')
	@PortDelayValue.setter
	def PortDelayValue(self, value):
		self._set_attribute('portDelayValue', value)

	@property
	def ProtocolItem(self):
		"""DEPRECATED Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def RandomLoadUnit(self):
		"""DEPRECATED The random values of the load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('randomLoadUnit')
	@RandomLoadUnit.setter
	def RandomLoadUnit(self, value):
		self._set_attribute('randomLoadUnit', value)

	@property
	def RateSelect(self):
		"""DEPRECATED The rate selected.

		Returns:
			str(fpsRate|kbpsRate|percentMaxRate)
		"""
		return self._get_attribute('rateSelect')
	@RateSelect.setter
	def RateSelect(self, value):
		self._set_attribute('rateSelect', value)

	@property
	def ReportSequenceError(self):
		"""DEPRECATED Reports sequence errors in the test result.

		Returns:
			bool
		"""
		return self._get_attribute('reportSequenceError')
	@ReportSequenceError.setter
	def ReportSequenceError(self, value):
		self._set_attribute('reportSequenceError', value)

	@property
	def ReportTputRateUnit(self):
		"""DEPRECATED The unit of rate for throughput.

		Returns:
			str(gbps|gBps|kbps|kBps|mbps|mBps)
		"""
		return self._get_attribute('reportTputRateUnit')
	@ReportTputRateUnit.setter
	def ReportTputRateUnit(self, value):
		self._set_attribute('reportTputRateUnit', value)

	@property
	def Resolution(self):
		"""DEPRECATED Specify the resolution of the iteration. The difference between the real rate transmission in two consecutive iterations, expressed as a percentage, is compared with the resolution value. When the difference is smaller than the value specified for the resolution, the test stops.

		Returns:
			number
		"""
		return self._get_attribute('resolution')
	@Resolution.setter
	def Resolution(self, value):
		self._set_attribute('resolution', value)

	@property
	def Rfc2544ImixDataQoS(self):
		"""DEPRECATED If true, it uses the same frame data qos

		Returns:
			bool
		"""
		return self._get_attribute('rfc2544ImixDataQoS')
	@Rfc2544ImixDataQoS.setter
	def Rfc2544ImixDataQoS(self, value):
		self._set_attribute('rfc2544ImixDataQoS', value)

	@property
	def Rfc2889ordering(self):
		"""DEPRECATED If true, indicates frame ordering by Rfc2889.

		Returns:
			str(noOrdering|peakLoading|unchanged|val2889Ordering)
		"""
		return self._get_attribute('rfc2889ordering')
	@Rfc2889ordering.setter
	def Rfc2889ordering(self, value):
		self._set_attribute('rfc2889ordering', value)

	@property
	def Runmode(self):
		"""DEPRECATED Specifies the number of frames that IxNetwork sends from each port in running mode.

		Returns:
			str(duration|noframes)
		"""
		return self._get_attribute('runmode')
	@Runmode.setter
	def Runmode(self, value):
		self._set_attribute('runmode', value)

	@property
	def SendFullyMeshed(self):
		"""DEPRECATED Indicates the source group mapping type used for sending data.

		Returns:
			bool
		"""
		return self._get_attribute('sendFullyMeshed')
	@SendFullyMeshed.setter
	def SendFullyMeshed(self, value):
		self._set_attribute('sendFullyMeshed', value)

	@property
	def ShowDetailedBinaryResults(self):
		"""DEPRECATED 

		Returns:
			bool
		"""
		return self._get_attribute('showDetailedBinaryResults')
	@ShowDetailedBinaryResults.setter
	def ShowDetailedBinaryResults(self, value):
		self._set_attribute('showDetailedBinaryResults', value)

	@property
	def StaggeredStart(self):
		"""DEPRECATED Starts test with a stagger.

		Returns:
			bool
		"""
		return self._get_attribute('staggeredStart')
	@StaggeredStart.setter
	def StaggeredStart(self, value):
		self._set_attribute('staggeredStart', value)

	@property
	def StepIncrementFrameSize(self):
		"""DEPRECATED The incremental step value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('stepIncrementFrameSize')
	@StepIncrementFrameSize.setter
	def StepIncrementFrameSize(self, value):
		self._set_attribute('stepIncrementFrameSize', value)

	@property
	def StepIncrementIpv4Ratio(self):
		"""DEPRECATED The step in which the ipv4 ratio loop is incremented

		Returns:
			str
		"""
		return self._get_attribute('stepIncrementIpv4Ratio')
	@StepIncrementIpv4Ratio.setter
	def StepIncrementIpv4Ratio(self, value):
		self._set_attribute('stepIncrementIpv4Ratio', value)

	@property
	def StepIncrementIpv6Ratio(self):
		"""DEPRECATED The step in which the ipv6 ratio loop is incremented

		Returns:
			str
		"""
		return self._get_attribute('stepIncrementIpv6Ratio')
	@StepIncrementIpv6Ratio.setter
	def StepIncrementIpv6Ratio(self, value):
		self._set_attribute('stepIncrementIpv6Ratio', value)

	@property
	def StepIncrementLoadRate(self):
		"""DEPRECATED The step incremental value of the load rate.

		Returns:
			number
		"""
		return self._get_attribute('stepIncrementLoadRate')
	@StepIncrementLoadRate.setter
	def StepIncrementLoadRate(self, value):
		self._set_attribute('stepIncrementLoadRate', value)

	@property
	def StepLoadRateFormula(self):
		"""DEPRECATED 

		Returns:
			str
		"""
		return self._get_attribute('stepLoadRateFormula')
	@StepLoadRateFormula.setter
	def StepLoadRateFormula(self, value):
		self._set_attribute('stepLoadRateFormula', value)

	@property
	def StepLoadUnit(self):
		"""DEPRECATED Specifies the step rate of the load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('stepLoadUnit')
	@StepLoadUnit.setter
	def StepLoadUnit(self, value):
		self._set_attribute('stepLoadUnit', value)

	@property
	def StepStepLoadRate(self):
		"""DEPRECATED The incremental step value of load rate.

		Returns:
			number
		"""
		return self._get_attribute('stepStepLoadRate')
	@StepStepLoadRate.setter
	def StepStepLoadRate(self, value):
		self._set_attribute('stepStepLoadRate', value)

	@property
	def StepTiLoss(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('stepTiLoss')
	@StepTiLoss.setter
	def StepTiLoss(self, value):
		self._set_attribute('stepTiLoss', value)

	@property
	def StepTolerance(self):
		"""DEPRECATED The step value of the tolerance level.

		Returns:
			number
		"""
		return self._get_attribute('stepTolerance')
	@StepTolerance.setter
	def StepTolerance(self, value):
		self._set_attribute('stepTolerance', value)

	@property
	def SupportedTrafficTypes(self):
		"""DEPRECATED The traffic types supported.

		Returns:
			str
		"""
		return self._get_attribute('supportedTrafficTypes')
	@SupportedTrafficTypes.setter
	def SupportedTrafficTypes(self, value):
		self._set_attribute('supportedTrafficTypes', value)

	@property
	def Tolerance(self):
		"""DEPRECATED The value set for the tolerance level.

		Returns:
			number
		"""
		return self._get_attribute('tolerance')
	@Tolerance.setter
	def Tolerance(self, value):
		self._set_attribute('tolerance', value)

	@property
	def TrafficType(self):
		"""DEPRECATED The test based on the traffic type.

		Returns:
			str(burstyLoading|constantLoading)
		"""
		return self._get_attribute('trafficType')
	@TrafficType.setter
	def TrafficType(self, value):
		self._set_attribute('trafficType', value)

	@property
	def TxDelay(self):
		"""DEPRECATED Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('txDelay')
	@TxDelay.setter
	def TxDelay(self, value):
		self._set_attribute('txDelay', value)

	@property
	def UnchangedValueList(self):
		"""DEPRECATED The number of unchanged sessions.

		Returns:
			str
		"""
		return self._get_attribute('unchangedValueList')
	@UnchangedValueList.setter
	def UnchangedValueList(self, value):
		self._set_attribute('unchangedValueList', value)

	@property
	def UseTiLoss(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('useTiLoss')
	@UseTiLoss.setter
	def UseTiLoss(self, value):
		self._set_attribute('useTiLoss', value)

	def update(self, BurstSize=None, CalculateJitter=None, CalculateLatency=None, CalibrateLatency=None, CountRandomFrameSize=None, CountRandomIpRatio=None, CountRandomLoadRate=None, CustomLoadUnit=None, DelayAfterTransmit=None, DetailedResultsEnabled=None, Duration=None, EnableDataIntegrity=None, EnableLayer1Rate=None, EnableMinFrameSize=None, EnableOldStatsForReef=None, FloodedFramesEnabled=None, ForceRegenerate=None, FrameSizeMode=None, FramesPerBurstGap=None, Framesize=None, FramesizeImixList=None, FramesizeList=None, Gap=None, GenerateTrackingOptionAggregationFiles=None, Grain=None, ImixAdd=None, ImixData=None, ImixDelete=None, ImixDistribution=None, ImixEnabled=None, ImixTemplates=None, ImixTrafficType=None, IncrementLoadUnit=None, InitialIncrementLoadRate=None, InitialStepLoadRate=None, IpRatioMode=None, Ipv4RatioList=None, Ipv4rate=None, Ipv6RatioList=None, Ipv6rate=None, LatencyBins=None, LatencyBinsEnabled=None, LatencyType=None, LoadRateList=None, LoadType=None, LoadUnit=None, MapType=None, MaxIncrementFrameSize=None, MaxIncrementIpv4Ratio=None, MaxIncrementIpv6Ratio=None, MaxIncrementLoadRate=None, MaxRandomFrameSize=None, MaxRandomIpv4Ratio=None, MaxRandomIpv6Ratio=None, MaxRandomLoadRate=None, MaxStepLoadRate=None, MinFpsRate=None, MinIncrementFrameSize=None, MinIncrementIpv4Ratio=None, MinIncrementIpv6Ratio=None, MinKbpsRate=None, MinRandomFrameSize=None, MinRandomIpv4Ratio=None, MinRandomIpv6Ratio=None, MinRandomLoadRate=None, MinStepLoadRate=None, NumFrames=None, Numtrials=None, PeakLoadingReplicationCount=None, PerTrafficResults=None, PercentMaxRate=None, PortDelayEnabled=None, PortDelayUnit=None, PortDelayValue=None, ProtocolItem=None, RandomLoadUnit=None, RateSelect=None, ReportSequenceError=None, ReportTputRateUnit=None, Resolution=None, Rfc2544ImixDataQoS=None, Rfc2889ordering=None, Runmode=None, SendFullyMeshed=None, ShowDetailedBinaryResults=None, StaggeredStart=None, StepIncrementFrameSize=None, StepIncrementIpv4Ratio=None, StepIncrementIpv6Ratio=None, StepIncrementLoadRate=None, StepLoadRateFormula=None, StepLoadUnit=None, StepStepLoadRate=None, StepTiLoss=None, StepTolerance=None, SupportedTrafficTypes=None, Tolerance=None, TrafficType=None, TxDelay=None, UnchangedValueList=None, UseTiLoss=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			BurstSize (number): The number of packets to send in a burst.
			CalculateJitter (bool): If true, the jitter is calculated.
			CalculateLatency (bool): If true, calculates the latency.
			CalibrateLatency (bool): If true, calibrates the latency.
			CountRandomFrameSize (number): If true, randomly counts the frame size.
			CountRandomIpRatio (number): Sets the count of the random ip ratio loop
			CountRandomLoadRate (number): The random count of the load rate.
			CustomLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): Specifies the custom load unit.
			DelayAfterTransmit (number): Specifies the amount of delay after every transmit.
			DetailedResultsEnabled (bool): If true, it enables the detailed results for the fully meshed case
			Duration (number): The duration of the test in hours, which is used to calculate the number of frames to transmit.
			EnableDataIntegrity (bool): If true, enables the checking of data integrity for the pass or fail of the trial.
			EnableLayer1Rate (bool): NOT DEFINED
			EnableMinFrameSize (bool): If true, enables minimum frame size.
			EnableOldStatsForReef (bool): If true, enables old statistics for reef load module.
			FloodedFramesEnabled (bool): If true, it enables the flooded frames statistics
			ForceRegenerate (bool): Initiates a forced regeneration.
			FrameSizeMode (str(custom|increment|random|unchanged)): This attribute is the frame size mode for the Quad Gaussian.
			FramesPerBurstGap (number): The number of frames to be sent after each burst.
			Framesize (str): The frame size to be used.
			FramesizeImixList (str): The list of the available lmix frame sizes.
			FramesizeList (list(str)): The list of the available frame sizes.
			Gap (number): The gap in transmission of frames.
			GenerateTrackingOptionAggregationFiles (bool): If true, enables the tracking option in aggregation files.
			Grain (str(coarse|fine)): The granular value of the test parameter.
			ImixAdd (str): Adds an imix data.
			ImixData (str): Displays imix data.
			ImixDelete (str): Deletes an imix data.
			ImixDistribution (str(bwpercentage|weight)): Shows the distribution of imix data.
			ImixEnabled (bool): If True, Enables the imix value.
			ImixTemplates (str(cisco|imix|ipsec|ipv6|none|quadmodal|standard|tcp|tolly|trimodal)): Specefies the imix templates.
			ImixTrafficType (str): Displays the imix traffic type.
			IncrementLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): The unit increment for the load.
			InitialIncrementLoadRate (number): The initial incremental value of the load rate.
			InitialStepLoadRate (number): The initial step value of the load rate.
			IpRatioMode (str(custom|fixed|increment|random)): Sets the ip ratio mode
			Ipv4RatioList (str): Sets the ipv4 ratio list
			Ipv4rate (number): The rate at which IPv4 traffic is sent.
			Ipv6RatioList (str): Sets the ipv6 ratio list
			Ipv6rate (number): The rate at which IPv6 traffic is sent.
			LatencyBins (str): Sets the latency bins statistics.
			LatencyBinsEnabled (bool): Enables the latency bins statistics.
			LatencyType (str(cutThrough|forwardingDelay|mef|storeForward)): The type of latency.
			LoadRateList (str): Enters the Load Rate List.
			LoadType (str(step)): The type of the payload setting.
			LoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): The load unit value.
			MapType (str): The mapping type.
			MaxIncrementFrameSize (number): The maximum incremental value of the frame size.
			MaxIncrementIpv4Ratio (str): Sets the maximum increment value for the ipv4 ratio
			MaxIncrementIpv6Ratio (str): Sets the maximum increment value for the ipv6 ratio
			MaxIncrementLoadRate (number): The maximum incremental value of the load rate.
			MaxRandomFrameSize (number): The maximum random frame size to be sent.
			MaxRandomIpv4Ratio (str): Sets the maximum radom value for the ipv4 ratio
			MaxRandomIpv6Ratio (str): Sets the maximum random value for the ipv6 ratio
			MaxRandomLoadRate (number): The maximum random value of the load rate.
			MaxStepLoadRate (number): The maximum step value of the load rate.
			MinFpsRate (number): The rate at which minimum frames are sent per second.
			MinIncrementFrameSize (number): The minimum incremental value of the frame size.
			MinIncrementIpv4Ratio (str): Sets the minimum increment value for the ipv4 ratio
			MinIncrementIpv6Ratio (str): Sets the minimum increment value for the ipv6 ratio
			MinKbpsRate (number): The rate at which minimum frames are sent per kbps.
			MinRandomFrameSize (number): The minimum random frame size to be sent.
			MinRandomIpv4Ratio (str): Sets the minimum random value for the ipv4 ratio
			MinRandomIpv6Ratio (str): Sets the minimum random value for the ipv6 ratio
			MinRandomLoadRate (number): The maximum random value of the load rate.
			MinStepLoadRate (number): The minimum step value of load rate.
			NumFrames (number): The number of frames sent.
			Numtrials (number): The integer value that states the number of trials permitted.
			PeakLoadingReplicationCount (number): NOT DEFINED
			PerTrafficResults (bool): 
			PercentMaxRate (number): The maximum percentage rate.
			PortDelayEnabled (bool): Enables the port delay.
			PortDelayUnit (str(bytes|nanoseconds)): Sets the port delay unit in which it will be measured
			PortDelayValue (number): Sets the port delay value.
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			RandomLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): The random values of the load unit.
			RateSelect (str(fpsRate|kbpsRate|percentMaxRate)): The rate selected.
			ReportSequenceError (bool): Reports sequence errors in the test result.
			ReportTputRateUnit (str(gbps|gBps|kbps|kBps|mbps|mBps)): The unit of rate for throughput.
			Resolution (number): Specify the resolution of the iteration. The difference between the real rate transmission in two consecutive iterations, expressed as a percentage, is compared with the resolution value. When the difference is smaller than the value specified for the resolution, the test stops.
			Rfc2544ImixDataQoS (bool): If true, it uses the same frame data qos
			Rfc2889ordering (str(noOrdering|peakLoading|unchanged|val2889Ordering)): If true, indicates frame ordering by Rfc2889.
			Runmode (str(duration|noframes)): Specifies the number of frames that IxNetwork sends from each port in running mode.
			SendFullyMeshed (bool): Indicates the source group mapping type used for sending data.
			ShowDetailedBinaryResults (bool): 
			StaggeredStart (bool): Starts test with a stagger.
			StepIncrementFrameSize (number): The incremental step value of the frame size.
			StepIncrementIpv4Ratio (str): The step in which the ipv4 ratio loop is incremented
			StepIncrementIpv6Ratio (str): The step in which the ipv6 ratio loop is incremented
			StepIncrementLoadRate (number): The step incremental value of the load rate.
			StepLoadRateFormula (str): 
			StepLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): Specifies the step rate of the load unit.
			StepStepLoadRate (number): The incremental step value of load rate.
			StepTiLoss (bool): NOT DEFINED
			StepTolerance (number): The step value of the tolerance level.
			SupportedTrafficTypes (str): The traffic types supported.
			Tolerance (number): The value set for the tolerance level.
			TrafficType (str(burstyLoading|constantLoading)): The test based on the traffic type.
			TxDelay (number): Specifies the amount of delay after every transmit.
			UnchangedValueList (str): The number of unchanged sessions.
			UseTiLoss (str): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class EvpnMac(Base):
	"""The EvpnMac class encapsulates a system managed evpnMac node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the EvpnMac property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'evpnMac'

	def __init__(self, parent):
		super(EvpnMac, self).__init__(parent)

	@property
	def NextHopInfo(self):
		"""An instance of the NextHopInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.nexthopinfo.NextHopInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.nexthopinfo import NextHopInfo
		return NextHopInfo(self)

	@property
	def Esi(self):
		"""(Read Only) Ethernet Segment Identifier.

		Returns:
			str
		"""
		return self._get_attribute('esi')

	@property
	def MacAddress(self):
		"""(Read Only) The C-MAC or the B-MAC address learned.

		Returns:
			str
		"""
		return self._get_attribute('macAddress')

	@property
	def MacPrefixLen(self):
		"""(Read Only) Prefix length of the learned C-MAC or B-MAC.

		Returns:
			str
		"""
		return self._get_attribute('macPrefixLen')

	@property
	def Neighbor(self):
		"""(Read Only) The neighbor IP.

		Returns:
			str
		"""
		return self._get_attribute('neighbor')

	def find(self, Esi=None, MacAddress=None, MacPrefixLen=None, Neighbor=None):
		"""Finds and retrieves evpnMac data from the server.

		All named parameters support regex and can be used to selectively retrieve evpnMac data from the server.
		By default the find method takes no parameters and will retrieve all evpnMac data from the server.

		Args:
			Esi (str): (Read Only) Ethernet Segment Identifier.
			MacAddress (str): (Read Only) The C-MAC or the B-MAC address learned.
			MacPrefixLen (str): (Read Only) Prefix length of the learned C-MAC or B-MAC.
			Neighbor (str): (Read Only) The neighbor IP.

		Returns:
			self: This instance with matching evpnMac data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of evpnMac data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the evpnMac data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)
